==> mysql-router-2.0.3.tar.gz: mysql-router-2.0.3/mysql_harness/shared/src/test_helpers.cc <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "test/helpers.h"

#include "loader.h"

::testing::AssertionResult
AssertLoaderSectionAvailable(const char *loader_expr,
                             const char *section_expr,
                             Loader* loader,
                             const std::string& section_name)
{
  auto lst = loader->available();
  auto match_example = [&section_name](const std::pair<std::string, std::string>& elem){
    return elem.first == section_name;
  };

  if (std::count_if(lst.begin(), lst.end(), match_example) > 0)
    return ::testing::AssertionSuccess();

  std::ostringstream sections;
  for (auto& name : lst) {
    sections << " " << name.first;
    if (!name.second.empty()) {
      sections << ":" << name.second;
    }
  }
  return ::testing::AssertionFailure()
         << "Loader '" << loader_expr << "' did not contain section '"
         << section_name << "' (from expression '" << section_expr << "')\n"
         << "Sections were: " << sections.str();
}

==> mysql-router-2.0.4.tar.gz: mysql-router-2.0.4/mysql_harness/shared/src/test_helpers.cc <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "test/helpers.h"

#include "loader.h"

::testing::AssertionResult
AssertLoaderSectionAvailable(const char *loader_expr,
                             const char *section_expr,
                             mysql_harness::Loader* loader,
                             const std::string& section_name) {
  using std::pair;
  using std::string;

  auto lst = loader->available();
  auto match_example = [&section_name](const pair<string, string>& elem){
    return elem.first == section_name;
  };

  if (std::count_if(lst.begin(), lst.end(), match_example) > 0)
    return ::testing::AssertionSuccess();

  std::ostringstream sections;
  for (auto& name : lst) {
    sections << " " << name.first;
    if (!name.second.empty()) {
      sections << ":" << name.second;
    }
  }
  return ::testing::AssertionFailure()
         << "Loader '" << loader_expr << "' did not contain section '"
         << section_name << "' (from expression '" << section_expr << "')\n"
         << "Sections were: " << sections.str();
}
